package org.me.hornetq.test.producer;

import java.io.IOException;

import javax.annotation.Resource;
import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.JMSException;
import javax.jms.MessageProducer;
import javax.jms.Queue;
import javax.jms.Session;
import javax.jms.TextMessage;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@WebServlet("/test")
@SuppressWarnings("serial")
public class HornetQProducerServlet extends HttpServlet {

	private static final Logger logger = LoggerFactory
			.getLogger(HornetQProducerServlet.class);

	@Resource(mappedName = "java:/ConnectionFactory")
	private ConnectionFactory connectionFactory;

	@Resource(mappedName = "java:/queue/testQueue")
	private Queue queue;

	@Override
	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {
		Session session = null;
		Connection connection = null;

		try {
			connection = connectionFactory.createConnection();

			session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);

			MessageProducer producer = session.createProducer(queue);

			connection.start();

			for (int i = 0; i < 5000; i++) {
				TextMessage message = session.createTextMessage();

				String messageText = "test_" + i;

				message.setText(messageText);

				logger.info("Sending message: " + messageText);

				producer.send(message);
			}
		} catch (Exception e) {
			logger.error("Internal error", e);

			resp.getWriter().println("ERROR");

			return;
		} finally {
			if (session != null) {
				try {
					session.close();
				} catch (JMSException e) {
					logger.error("Error while closing session", e);
				}
			}

			if (connection != null) {
				try {
					connection.close();
				} catch (JMSException e) {
					logger.error("Error while closing connection", e);
				}
			}
		}

		resp.getWriter().println("OK");
	}

}
